@@ -52,7 +52,7 @@
 #'   tax="genus", bin="stg", output="dist", keep=95)
 #' 	
 #' # plotting
-#'   tsplot(stages, shading="series", boxes="per", xlim=c(260,0), 
+#'   tsplot(stages, shading="series", boxes="sys", xlim=c(260,0), 
 #'   ylab="range-through diversity (genera)", ylim=c(0,230))
 #'   lines(stages$mid, dd$divRT, lwd=2)
 #'   shades(stages$mid, rarefDD$divRT, col="blue")
@@ -68,7 +68,7 @@
 #'   calc<-tapply(INDEX=dat[,bin], X=dat[,tax], function(y){
 #'     length(levels(factor(y)))
 #'   })
-#'   return(calc[as.character(stages$num)])
+#'   return(calc[as.character(stages$stg)])
 #' }
 #' sibDiv<-sib(corals, bin="stg", tax="genus")
 #' 
@@ -79,7 +79,7 @@
 #'   tax="genus", bin="stg", output="arit", keep=95)
 #' 
 #' # plot
-#' tsplot(stages, shading="series", boxes="per", xlim=c(260,0), 
+#' tsplot(stages, shading="series", boxes="sys", xlim=c(260,0), 
 #'   ylab="SIB diversity (genera)", ylim=c(0,230))
 #' 
 #' lines(stages$mid, rarefDD$divSIB, lwd=2, col="black")
@@ -100,7 +100,7 @@
 #'   SQS<-subsample(corals,iter=50, q=0.4,tax="genus", bin="stg", output="dist", keep=95, type="sqs")
 #'
 #' # plot
-#'   tsplot(stages, shading="series", boxes="per", xlim=c(260,0), 
+#'   tsplot(stages, shading="series", boxes="sys", xlim=c(260,0), 
 #'   ylab="range-through diversity (genera)", ylim=c(0,100))
 #'   shades(stages$mid, cr$divRT, col="red")
 #'   shades(stages$mid, UW$divRT, col="blue")
@@ -1311,12 +1311,18 @@ subsampleSQSinexact<-function(binVar, freqVar, q, collVar=NULL, byList=FALSE, in
 			if(length(cumulative)>0){
 				if(cumulative[length(cumulative)]>q){
 					bSelect<-cumulative<=q
+
 					# potential forking!!! 
 					if(appr=="over"){
 						if(sum(bSelect)!=length(bSelect)){
 							bSelect[sum(bSelect)+1] <- TRUE
 						}
 					}
+
+					# if first selected species have larger then quorum frequency 
+					if(appr=="under" & sum(bSelect)==0){
+						bSelect[1]<-TRUE	
+					}
 					
 					# the species to keep
 					keepTaxa<-speciesFirstEncounterOrder[bSelect]
@@ -1433,4 +1439,3 @@ subsampleSQSinexact<-function(binVar, freqVar, q, collVar=NULL, byList=FALSE, in
 	return(res)
 
 }
-
